import 'dart:io' show Directory;
import 'package:path/path.dart' show join;

import 'env.dart';

abstract class Meta {
  String getDebugPath();
  String getReleasePath();
  String getCurrentPath();
}

class Windows implements Meta {
  static const String assets = 'data\\flutter_assets';

  @override
  String getDebugPath() =>
      join(Directory.current.path, 'build\\windows\\runner\\Debug', assets);

  @override
  String getReleasePath() => join(Directory.current.path, assets);

  @override
  String getCurrentPath() => isProduct() ? getReleasePath() : getDebugPath();
}

class Linux implements Meta {
  static const String assets = 'data/flutter_assets';

  String getDebugPath() =>
      join(Directory.current.path, 'build/linux/debug/bundle', assets);

  @override
  String getReleasePath() => join(Directory.current.path, assets);

  @override
  String getCurrentPath() => isProduct() ? getReleasePath() : getDebugPath();
}

class Macos implements Meta {
  static const String assets = 'data/flutter_assets';

  @Deprecated("I doesn't have a Mac, and doesn't know the path relationship in debug mode")
  @override
  String getDebugPath() {
    throw UnimplementedError();
  }

  @override
  String getReleasePath() => join(Directory.current.path, assets);

  @override
  String getCurrentPath() => isProduct() ? getReleasePath() : getDebugPath();
}
